********
Showcase
********

This collection of examples demonstrate interesting uses of HoloViews
that go beyond the user guide material. Suitable material includes
application of HoloViews to real-world data, and examples of advanced
usage and demonstrations of how HoloViews may be extended, including
third-party libraries that feature HoloViews integration.

We hope this set of examples will be a useful way of discovering what
is possible with HoloViews. We welcome your submissions for inclusion on
this list as HoloViews is applied to new domains.


Geographic information systems
------------------------------

* `GeoViews <http://geo.holoviews.org>`_ is an officially supported
  extension for HoloViews to work with geographic data. It adds
  support for projecting geographic data, support for shape data,
  various geographic features and tile sources.

Geometry
--------

* `L-Systems <lsystems.html>`_

* `Square-Limit <square_limit.html>`_

Simulation
----------

This collection of IPython notebooks shows real-world examples of how
HoloViews may be used:

* `Boids <boids.html>`_

* `The Hipster Effect <hipster_dynamics.html>`_: Adapted version of `post from Jake Vanderplas
  <https://jakevdp.github.io/blog/2014/11/11/the-hipster-effect-interactive>`_
  about dynamic systems and modeling of conformity.

* `Exploring herd immunity with agent based models using HoloViews and NetworkX <sri_model.html>`_: A small demo demonstrating how HoloViews can be integrated with a simple agent based model to explore and analyze how it evolves over time.

* `Topographica tutorials <http://topographica.org/Tutorials/>`_:
  Neural simulator using HoloViews (plus publications `Stevens et
  al. (2013)
  <http://homepages.inf.ed.ac.uk/jbednar/papers/stevens.jn13.pdf>`_,
  `Gee (2014)
  <http://homepages.inf.ed.ac.uk/jbednar/papers/gee.ms14.pdf>`_, and
  `Fischer (2014)
  <http://homepages.inf.ed.ac.uk/jbednar/papers/gee.ms14.pdf>`_ with
  `associated notebook
  <http://ioam.github.io/topographica/Tutorials/gcal_all.html>`_)


Other libraries and resources
-----------------------------

Third party libraries, simulators and toolkits that make use of
HoloViews for easier visualization and analysis:

* `ImaGen library <http://ioam.github.io/imagen>`_: Generate
  HoloViews `Image <https://holoviews/reference/elements/bokeh/Image.html>`_
  and 
  `RGB <https://holoviews/reference/elements/bokeh/RGB.html>`_ 
  patterns from mathematical functions.

* `Topology in Condensed Matter course <https://topocondmat.org/>`_:
  Tying Quantum Knots. This course also runs on `EdX <http://tiny.cc/topocm>`_.
  See for example the lecture on the `Haldane model 
  <https://topocondmat.org/w4_haldane/haldane_model.html>`_ (view as `notebook 
  <https://nbviewer.jupyter.org/url/topocondmat.org/notebooks/w4_haldane/haldane_model.ipynb>`_) or on 
  `Floquet topological insulators 
  <https://topocondmat.org/w11_extensions2/floquet.html>`_ (view as `notebook 
  <https://nbviewer.jupyter.org/url/topocondmat.org/notebooks/w11_extensions2/floquet.ipynb>`_). The 
  source is availible on `GitHub 
  <https://github.com/topocm/topocm_content>`_.
